@@ -28,7 +28,8 @@ fun._settings  = settings
 data._settings = settings
 
 # Get the version
-exec(fun.read_lines(_os.path.join(__path__[0],'setup.py'))[0])
+try: exec(fun.read_lines(_os.path.join(__path__[0],'setup.py'))[0])
+except: __version__ = 'unknown'
 
 
 def _warn(*args):
